==> istio-model-v1alpha3-6.8.1-sources.jar: io/fabric8/istio/api/networking/v1alpha3/ReadinessProbeTcpSocketFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ReadinessProbeTcpSocketFluent<A extends ReadinessProbeTcpSocketFluent<A>> extends BaseFluent<A>{
  public ReadinessProbeTcpSocketFluent() {
  }
  public ReadinessProbeTcpSocketFluent(ReadinessProbeTcpSocket instance) {
    instance = (instance != null ? instance : new ReadinessProbeTcpSocket());

    if (instance != null) {
      this.withTcpSocket(instance.getTcpSocket());
      this.withTcpSocket(instance.getTcpSocket());
    }
  }
  private TCPHealthCheckConfigBuilder tcpSocket;
  public TCPHealthCheckConfig buildTcpSocket() {
    return this.tcpSocket!=null ?this.tcpSocket.build():null;
  }
  public A withTcpSocket(TCPHealthCheckConfig tcpSocket) {
    _visitables.get("tcpSocket").remove(this.tcpSocket);
    if (tcpSocket!=null){ this.tcpSocket= new TCPHealthCheckConfigBuilder(tcpSocket); _visitables.get("tcpSocket").add(this.tcpSocket);} else { this.tcpSocket = null; _visitables.get("tcpSocket").remove(this.tcpSocket); } return (A) this;
  }
  public boolean hasTcpSocket() {
    return this.tcpSocket != null;
  }
  public A withNewTcpSocket(String host,Integer port) {
    return (A)withTcpSocket(new TCPHealthCheckConfig(host, port));
  }
  public TcpSocketNested<A> withNewTcpSocket() {
    return new TcpSocketNested(null);
  }
  public TcpSocketNested<A> withNewTcpSocketLike(TCPHealthCheckConfig item) {
    return new TcpSocketNested(item);
  }
  public TcpSocketNested<A> editTcpSocket() {
    return withNewTcpSocketLike(java.util.Optional.ofNullable(buildTcpSocket()).orElse(null));
  }
  public TcpSocketNested<A> editOrNewTcpSocket() {
    return withNewTcpSocketLike(java.util.Optional.ofNullable(buildTcpSocket()).orElse(new TCPHealthCheckConfigBuilder().build()));
  }
  public TcpSocketNested<A> editOrNewTcpSocketLike(TCPHealthCheckConfig item) {
    return withNewTcpSocketLike(java.util.Optional.ofNullable(buildTcpSocket()).orElse(item));
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ReadinessProbeTcpSocketFluent that = (ReadinessProbeTcpSocketFluent) o;
    if (!java.util.Objects.equals(tcpSocket, that.tcpSocket)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(tcpSocket,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (tcpSocket != null) { sb.append("tcpSocket:"); sb.append(tcpSocket); }
    sb.append("}");
    return sb.toString();
  }
  public class TcpSocketNested<N> extends TCPHealthCheckConfigFluent<TcpSocketNested<N>> implements Nested<N>{
    TcpSocketNested(TCPHealthCheckConfig item) {
      this.builder = new TCPHealthCheckConfigBuilder(this, item);
    }
    TCPHealthCheckConfigBuilder builder;
    public N and() {
      return (N) ReadinessProbeTcpSocketFluent.this.withTcpSocket(builder.build());
    }
    public N endTcpSocket() {
      return and();
    }
    
  }
  
}

==> istio-model-v1alpha3-6.9.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/ReadinessProbeTcpSocketFluent.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Integer;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ReadinessProbeTcpSocketFluent<A extends ReadinessProbeTcpSocketFluent<A>> extends BaseFluent<A>{
  public ReadinessProbeTcpSocketFluent() {
  }
  
  public ReadinessProbeTcpSocketFluent(ReadinessProbeTcpSocket instance) {
    this.copyInstance(instance);
  }
  private TCPHealthCheckConfigBuilder tcpSocket;
  
  protected void copyInstance(ReadinessProbeTcpSocket instance) {
    instance = (instance != null ? instance : new ReadinessProbeTcpSocket());
  
    if (instance != null) {
        this.withTcpSocket(instance.getTcpSocket());
        this.withTcpSocket(instance.getTcpSocket());
      }
  }
  
  public TCPHealthCheckConfig buildTcpSocket() {
    return this.tcpSocket!=null ?this.tcpSocket.build():null;
  }
  
  public A withTcpSocket(TCPHealthCheckConfig tcpSocket) {
    _visitables.get("tcpSocket").remove(this.tcpSocket);
    if (tcpSocket!=null){ this.tcpSocket= new TCPHealthCheckConfigBuilder(tcpSocket); _visitables.get("tcpSocket").add(this.tcpSocket);} else { this.tcpSocket = null; _visitables.get("tcpSocket").remove(this.tcpSocket); } return (A) this;
  }
  
  public boolean hasTcpSocket() {
    return this.tcpSocket != null;
  }
  
  public A withNewTcpSocket(String host,Integer port) {
    return (A)withTcpSocket(new TCPHealthCheckConfig(host, port));
  }
  
  public TcpSocketNested<A> withNewTcpSocket() {
    return new TcpSocketNested(null);
  }
  
  public TcpSocketNested<A> withNewTcpSocketLike(TCPHealthCheckConfig item) {
    return new TcpSocketNested(item);
  }
  
  public TcpSocketNested<A> editTcpSocket() {
    return withNewTcpSocketLike(java.util.Optional.ofNullable(buildTcpSocket()).orElse(null));
  }
  
  public TcpSocketNested<A> editOrNewTcpSocket() {
    return withNewTcpSocketLike(java.util.Optional.ofNullable(buildTcpSocket()).orElse(new TCPHealthCheckConfigBuilder().build()));
  }
  
  public TcpSocketNested<A> editOrNewTcpSocketLike(TCPHealthCheckConfig item) {
    return withNewTcpSocketLike(java.util.Optional.ofNullable(buildTcpSocket()).orElse(item));
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ReadinessProbeTcpSocketFluent that = (ReadinessProbeTcpSocketFluent) o;
    if (!java.util.Objects.equals(tcpSocket, that.tcpSocket)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(tcpSocket,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (tcpSocket != null) { sb.append("tcpSocket:"); sb.append(tcpSocket); }
    sb.append("}");
    return sb.toString();
  }
  public class TcpSocketNested<N> extends TCPHealthCheckConfigFluent<TcpSocketNested<N>> implements Nested<N>{
    TcpSocketNested(TCPHealthCheckConfig item) {
      this.builder = new TCPHealthCheckConfigBuilder(this, item);
    }
    TCPHealthCheckConfigBuilder builder;
    
    public N and() {
      return (N) ReadinessProbeTcpSocketFluent.this.withTcpSocket(builder.build());
    }
    
    public N endTcpSocket() {
      return and();
    }
    
  
  }

}
